import sys
import os


TEST_SPATIAL = 'TEST_SPATIAL' in os.environ


SECRET_KEY = 'fake-key'

INSTALLED_APPS = [
    "location_field.apps.DefaultConfig",
    "tests",
]

STATIC_URL = '/static/'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'APP_DIRS': True,
    },
]


if TEST_SPATIAL:
    DATABASES = {
        'default': {
            'ENGINE': 'django.contrib.gis.db.backends.spatialite',
            'NAME': 'db.sqlite3',
        }
    }

    if sys.platform == 'darwin':
        SPATIALITE_LIBRARY_PATH = '/usr/local/lib/mod_spatialite.dylib'

else:
    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.sqlite3',
            'NAME': 'db.sqlite3',
        }
    }



class BaseLocationField(object):
    def __init__(self, **kwargs):
        self._based_fields = kwargs.pop('based_fields', [])
        self._zoom = kwargs.pop('zoom', 2)

    def formfield(self, **kwargs):
        return super(BaseLocationField, self).formfield(
            form_class=self.formfield_class,
            based_fields=self._based_fields,
            zoom=self._zoom,
            **kwargs)



from django.db import models

from location_field.models.plain import PlainLocationField


class Place(models.Model):
    parent_place = models.ForeignKey('self', blank=True, null=True)
    city = models.CharField(max_length=255)
    location = PlainLocationField(based_fields=['city'], zoom=7)
